AccessibleObjectId

Enum AccessibleObjectId 

#[repr(i32)]
pub enum AccessibleObjectId {
Show 15 variants Alert = -10, Caret = -8, Client = -4, Cursor = -9, HorizontalScroll = -6, NativeObjectModel = -16, Menu = -3, QueryClassNameIdx = -12, SizeGrip = -7, Sound = -11, SystemMenu = -1, TitleBar = -2, VerticalScroll = -5, Window = 0, Other(i32),
}
The type of object associated with a window event.

Variants



Alert = -10

An alert that is associated with a window or an application.



Caret = -8

The text insertion bar (caret) in the window.



Client = -4

The window’s client area.



Cursor = -9

The mouse pointer. There is only one mouse pointer in the system, and it is not a child of any window.



HorizontalScroll = -6

The window’s horizontal scroll bar.



NativeObjectModel = -16

In response to this object identifier, third-party applications can expose their own object model. Third-party applications can return any COM interface in response to this object identifier.



Menu = -3

The window’s menu bar.



QueryClassNameIdx = -12

An object identifier that Oleacc.dll uses internally. For more information, see Appendix F: Object Identifier Values for OBJID_QUERYCLASSNAMEIDX`.



SizeGrip = -7

The window’s size grip: an optional frame component located at the lower-right corner of the window frame.



Sound = -11

A sound object. Sound objects do not have screen locations or children, but they do have name and state attributes. They are children of the application that is playing the sound.



SystemMenu = -1

The window’s system menu.



TitleBar = -2

The window’s title bar.



VerticalScroll = -5

The window’s vertical scroll bar.



Window = 0

The window itself rather than a child object.



Other(i32)

Unknown object id