pub struct WindowEvent {
pub raw: RawWindowEvent,
}Expand description
A window event received by a WindowEventHook.
Fields
raw: RawWindowEventThe raw underlying event.
Implementations
Sourceimpl WindowEvent
impl WindowEvent
Sourcepub fn from_raw(raw: RawWindowEvent) -> Self
pub fn from_raw(raw: RawWindowEvent) -> Self
Creates a new WindowEvent from a raw event.
Sourcepub fn hook_handle(&self) -> HookHandle
pub fn hook_handle(&self) -> HookHandle
Returns the handle to the shared event hook function.
Sourcepub fn event_type(&self) -> WindowEventType
pub fn event_type(&self) -> WindowEventType
Returns the type of event that occurred.
Sourcepub fn window_handle(&self) -> Option<WindowHandle>
pub fn window_handle(&self) -> Option<WindowHandle>
Returns the handle to the window that generates the event, or None if no window is associated with the event.
Sourcepub fn object_type(&self) -> AccessibleObjectId
pub fn object_type(&self) -> AccessibleObjectId
Returns the type of object associated with the event.